@@ -1,9 +1,13 @@
+# Copyrights 2004-2007 by Mark Overmeer.
+# For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 0.99.
 use strict;
 use warnings;
 
 package Math::Polygon;
 use vars '$VERSION';
-$VERSION = '0.004';
+$VERSION = '0.96';
 
 use Math::Polygon::Calc;
 use Math::Polygon::Clip;
@@ -139,10 +143,13 @@ sub same($;@)
 
 sub contains($)
 {   my ($self, $point) = @_;
-    polygon_contains_point($point, shift->points);
+    polygon_contains_point($point, $self->points);
 }
 
 
+sub isClosed() { polygon_is_closed(shift->points) }
+
+
 sub resize(@)
 {   my $self = shift;
 
